@@ -1,4 +1,4 @@
-/* $Id: expense.c,v 1.52 2007/06/06 02:45:10 rikster5 Exp $ */
+/* $Id: expense.c,v 1.56 2008/05/25 09:46:20 rousseau Exp $ */
 
 /*******************************************************************************
  * expense.c
@@ -34,7 +34,7 @@
 #include <pi-file.h>
 
 #include "libplugin.h"
-#include "../i18n.h"
+#include "i18n.h"
 #include "utils.h"
 #include "prefs.h"
 #include "stock_buttons.h"
@@ -925,6 +925,12 @@ static void display_records()
    gtk_signal_disconnect_by_func(GTK_OBJECT(clist),
                                  GTK_SIGNAL_FUNC(cb_clist_selection), NULL);
    gtk_clist_clear(GTK_CLIST(clist));
+#ifdef __APPLE__
+   gtk_clist_thaw(GTK_CLIST(clist));
+   gtk_widget_hide(clist);
+   gtk_widget_show_all(clist);
+   gtk_clist_freeze(GTK_CLIST(clist));
+#endif
 
    /* This function takes care of reading the Database for us */
    num = jp_read_DB_files("ExpenseDB", &records);
@@ -1310,7 +1316,7 @@ static int make_menu(char *items[], int menu_index, GtkWidget **Poption_menu,
    group = NULL;
    
    for (i=0; items[i]; i++) {
-      menu_item = gtk_radio_menu_item_new_with_label(group, gettext(items[i]));
+      menu_item = gtk_radio_menu_item_new_with_label(group, _(items[i]));
       menu_items[i] = menu_item;
       if (menu_index==EXPENSE_CAT1) {
          if (i==0) {
@@ -1761,6 +1767,7 @@ int plugin_gui(GtkWidget *vbox, GtkWidget *hbox, unsigned int unique_id)
                              0, 1, 5, 6);
 #endif
    entry_amount = gtk_entry_new();
+   entry_set_multiline_truncate(GTK_ENTRY(entry_amount), TRUE);
    gtk_table_attach_defaults(GTK_TABLE(table), GTK_WIDGET(entry_amount),
                              1, 2, 5, 6);
 
@@ -1775,6 +1782,7 @@ int plugin_gui(GtkWidget *vbox, GtkWidget *hbox, unsigned int unique_id)
                              0, 1, 6, 7);
 #endif
    entry_vendor = gtk_entry_new();
+   entry_set_multiline_truncate(GTK_ENTRY(entry_vendor), TRUE);
    gtk_table_attach_defaults(GTK_TABLE(table), GTK_WIDGET(entry_vendor),
                              1, 2, 6, 7);
 
@@ -1789,6 +1797,7 @@ int plugin_gui(GtkWidget *vbox, GtkWidget *hbox, unsigned int unique_id)
                              0, 1, 7, 8);
 #endif
    entry_city = gtk_entry_new();
+   entry_set_multiline_truncate(GTK_ENTRY(entry_city), TRUE);
    gtk_table_attach_defaults(GTK_TABLE(table), GTK_WIDGET(entry_city),
                              1, 2, 7, 8);
 
