@@ -1,4 +1,7 @@
-/* import_gui.c
+/* $Id: import_gui.c,v 1.24 2008/04/27 16:32:31 rikster5 Exp $ */
+
+/*******************************************************************************
+ * import_gui.c
  * A module of J-Pilot http://jpilot.org
  *
  * Copyright (C) 1999-2002 by Judd Montgomery
@@ -15,7 +18,7 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
- */
+ ******************************************************************************/
 
 #include "config.h"
 #include "i18n.h"
@@ -58,7 +61,7 @@ int read_csv_field(FILE *in, char *text, int size, int new_line)
    while (1) {
       c=getc(in);
       if (feof(in)) {
-	 return 0;
+	 return EXIT_SUCCESS;
 	 text[++n]='\0';
       }
       if (!strchr(sep, c)) {
@@ -104,23 +107,6 @@ int read_csv_field(FILE *in, char *text, int size, int new_line)
    return n;
 }
 
-char *str_type(int type)
-{
-   switch (type) {
-    case IMPORT_TYPE_UNKNOWN:
-      return "IMPORT_TYPE_UNKNOWN";
-    case IMPORT_TYPE_TEXT:
-      return "IMPORT_TYPE_TEXT";
-    case IMPORT_TYPE_DAT:
-      return "IMPORT_TYPE_DAT";
-    case IMPORT_TYPE_CSV:
-      return "IMPORT_TYPE_CSV";
-    case IMPORT_TYPE_XML:
-      return "IMPORT_TYPE_XML";
-   }
-   return "?";
-}
-
 int guess_file_type(const char *path)
 {
    FILE *in;
@@ -208,6 +194,7 @@ cb_import(GtkWidget *widget,
       return;
    }
    glob_import_callback(filesel, sel, glob_type_selected);
+   cb_quit(widget, filew);
 }
 
 static void cb_import_select_row(GtkWidget *file_clist,
@@ -249,21 +236,19 @@ static void cb_import_select_row(GtkWidget *file_clist,
 void import_gui(GtkWidget *main_window, GtkWidget *main_pane,
 		char *type_desc[], int type_int[],
 		int (*import_callback)(GtkWidget *parent_window,
-				       const char *file_path, int type))
+	        const char *file_path, int type))
 {
    GtkWidget *button;
    GtkWidget *vbox, *hbox;
    GtkWidget *label;
-   char temp[256];
+   char title[256];
    const char *svalue;
    GSList *group;
    int i;
    int pw, ph, px, py;
 
-   if (filew) {
-      return;
-   }
-
+   if (filew) return;
+   
    line_selected = -1;
 
    gdk_window_get_size(main_window->window, &pw, &ph);
@@ -276,11 +261,11 @@ void import_gui(GtkWidget *main_window, GtkWidget *main_pane,
 #endif
    px+=40;
 
-   g_snprintf(temp, sizeof(temp), "%s %s", PN, _("Import"));
+   g_snprintf(title, sizeof(title), "%s %s", PN, _("Import"));
 
    filew = gtk_widget_new(GTK_TYPE_FILE_SELECTION,
 			  "type", GTK_WINDOW_TOPLEVEL,
-			  "title", temp,
+			  "title", title,
 			  NULL);
 
    gtk_window_set_default_size(GTK_WINDOW(filew), pw, ph);
@@ -305,7 +290,7 @@ void import_gui(GtkWidget *main_window, GtkWidget *main_pane,
 
    /*Even though I hide the ok button I still want to connect its signal */
    /*because a double click on the file name also calls this callback */
-   gtk_widget_hide(GTK_WIDGET(GTK_FILE_SELECTION(filew)->ok_button));   
+   gtk_widget_hide(GTK_WIDGET(GTK_FILE_SELECTION(filew)->ok_button));
    gtk_signal_connect(GTK_OBJECT(GTK_FILE_SELECTION(filew)->ok_button),
 		      "clicked", GTK_SIGNAL_FUNC(cb_import), filew);
 
@@ -315,6 +300,17 @@ void import_gui(GtkWidget *main_window, GtkWidget *main_pane,
    gtk_widget_show(label);
 
 
+#ifdef ENABLE_GTK2
+   button = gtk_button_new_from_stock(GTK_STOCK_CLOSE);
+#else
+   button = gtk_button_new_with_label(_("Done"));
+#endif
+   gtk_box_pack_start(GTK_BOX(GTK_FILE_SELECTION(filew)->ok_button->parent),
+		      button, TRUE, TRUE, 0);
+   gtk_signal_connect(GTK_OBJECT(button),
+		      "clicked", GTK_SIGNAL_FUNC(cb_quit), filew);
+   gtk_widget_show(button);
+
    button = gtk_button_new_with_label(_("Import"));
    gtk_box_pack_start(GTK_BOX(GTK_FILE_SELECTION(filew)->ok_button->parent),
 		      button, TRUE, TRUE, 0);
@@ -322,13 +318,6 @@ void import_gui(GtkWidget *main_window, GtkWidget *main_pane,
 		      "clicked", GTK_SIGNAL_FUNC(cb_import), filew);
    gtk_widget_show(button);
 
-   button = gtk_button_new_with_label(_("Done"));
-   gtk_box_pack_start(GTK_BOX(GTK_FILE_SELECTION(filew)->ok_button->parent),
-		      button, TRUE, TRUE, 0);
-   gtk_signal_connect(GTK_OBJECT(button),
-		      "clicked", GTK_SIGNAL_FUNC(cb_quit), filew);
-   gtk_widget_show(button);
-
    /* File Type */
    vbox=gtk_vbox_new(FALSE, 0);
    hbox=gtk_hbox_new(FALSE, 0);
@@ -367,7 +356,7 @@ void import_gui(GtkWidget *main_window, GtkWidget *main_pane,
 }
 
 
-/* 
+/*
  * Import record display and choice.
  * Put up the record for viewing and ask if it should be imported.
  */
@@ -408,6 +397,8 @@ int import_record_ask(GtkWidget *main_window, GtkWidget *pane,
    int pw, ph;
    gint px, py;
    char str[100];
+   char *l;
+   long char_set;
 
    /* There is no support yet for changing the suggested category */
    /* Like a menu for selecting cat to be imported into, etc. */
@@ -456,14 +447,18 @@ int import_record_ask(GtkWidget *main_window, GtkWidget *pane,
    gtk_box_pack_start(GTK_BOX(vbox), label, FALSE, FALSE, 0);
 
 
-   g_snprintf(str, sizeof(str), "Category before import was: [%s]", old_cat_name);
+   get_pref(PREF_CHAR_SET, &char_set, NULL);
+   l = charset_p2newj(old_cat_name, 17, char_set);
+   g_snprintf(str, sizeof(str), _("Category before import was: [%s]"), l);
+   g_free(l);
    label = gtk_label_new(str);
    gtk_misc_set_alignment(GTK_MISC(label), 0, 0);
    gtk_box_pack_start(GTK_BOX(vbox), label, FALSE, FALSE, 0);
 
 
-   g_snprintf(str, sizeof(str), "Record will be put in category [%s]",
-	      cai->name[suggested_cat_num]);
+   l = charset_p2newj(cai->name[suggested_cat_num], 17, char_set);
+   g_snprintf(str, sizeof(str), _("Record will be put in category [%s]"), l);
+   g_free(l);
    label = gtk_label_new(str);
    gtk_misc_set_alignment(GTK_MISC(label), 0, 0);
    gtk_box_pack_start(GTK_BOX(vbox), label, FALSE, FALSE, 0);
@@ -504,7 +499,9 @@ int import_record_ask(GtkWidget *main_window, GtkWidget *pane,
    }
 
    /* Box for buttons  */
-   temp_hbox = gtk_hbox_new(FALSE, 0);
+   temp_hbox = gtk_hbutton_box_new();
+   gtk_button_box_set_spacing(GTK_BUTTON_BOX(temp_hbox), 6);
+   gtk_container_set_border_width(GTK_CONTAINER(temp_hbox), 6);
    gtk_box_pack_start(GTK_BOX(vbox), temp_hbox, FALSE, FALSE, 0);
 
    /* Import button */
@@ -529,7 +526,11 @@ int import_record_ask(GtkWidget *main_window, GtkWidget *pane,
 		      GINT_TO_POINTER(DIALOG_SAID_IMPORT_SKIP));
 
    /* Quit button */
-   button = gtk_button_new_with_label(_("Quit"));
+#ifdef ENABLE_GTK2
+   button = gtk_button_new_from_stock(GTK_STOCK_CLOSE);
+#else
+   button = gtk_button_new_with_label(_("Close"));
+#endif
    gtk_box_pack_start(GTK_BOX(temp_hbox), button, TRUE, TRUE, 0);
    gtk_signal_connect(GTK_OBJECT(button), "clicked",
 		      GTK_SIGNAL_FUNC(cb_import_record_ask_quit),
