@@ -1,4 +1,4 @@
-/* $Id: jpilot.c,v 1.159 2007-11-25 12:19:21 rousseau Exp $ */
+/* $Id: jpilot.c,v 1.162 2008/05/14 18:46:20 rousseau Exp $ */
 
 /*******************************************************************************
  * jpilot.c
@@ -114,7 +114,7 @@ int glob_focus = 1;
 GtkWidget *glob_dialog=NULL;
 unsigned char skip_plugins;
 static GtkWidget *button_locked, *button_locked_masked, *button_unlocked, *button_sync, *button_backup;
-GtkCheckMenuItem *menu_hide_privates;
+GtkCheckMenuItem *menu_hide_privates, *menu_show_privates, *menu_mask_privates;
 int t_fmt_ampm = TRUE;
 
 int pipe_from_child, pipe_to_parent;
@@ -553,12 +553,18 @@ static void cb_private(GtkWidget *widget, gpointer data)
 {
    int privates, was_privates;
    int r_dialog = 0;
+   static int skip_false_call = 0;
 #ifdef ENABLE_PRIVATE
    char ascii_password[64];
    int r_pass;
    int retry;
 #endif
 
+   if (skip_false_call) {
+      skip_false_call = 0;
+      return;
+   }
+
    was_privates = show_privates(GET_PRIVATES);
    privates = show_privates(GPOINTER_TO_INT(data));
 
@@ -605,6 +611,23 @@ static void cb_private(GtkWidget *widget, gpointer data)
       break;
    }
 
+   if (widget) {
+      /* Setting the state of the menu causes a signal to be emitted which calls cb_private again.
+       * This second call needs to be ignored */
+      skip_false_call = 1;
+      switch (privates) {
+       case MASK_PRIVATES:
+         gtk_check_menu_item_set_active(menu_mask_privates, TRUE);
+         break;
+       case HIDE_PRIVATES:
+         gtk_check_menu_item_set_active(menu_hide_privates, TRUE);
+         break;
+       case SHOW_PRIVATES:
+         gtk_check_menu_item_set_active(menu_show_privates, TRUE);
+         break;
+      }
+   }
+
    if (was_privates != privates)
       cb_app_button(NULL, GINT_TO_POINTER(REDRAW));
 }
@@ -1122,7 +1145,7 @@ guint8 *get_inline_pixbuf_data(const char **xpm_icon_data, gint icon_size)
        gdk_pixbuf_get_height(pixbuf) != icon_size) {
       scaled_pb = gdk_pixbuf_scale_simple(pixbuf, icon_size, icon_size,
 	 GDK_INTERP_BILINEAR);
-      g_object_unref(G_OBJECT(pixbuf));
+      gdk_pixbuf_unref(pixbuf);
       pixbuf = scaled_pb;
    }
 
@@ -1130,7 +1153,7 @@ guint8 *get_inline_pixbuf_data(const char **xpm_icon_data, gint icon_size)
    gdk_pixdata_from_pixbuf(pixdata, pixbuf, FALSE);
    data = gdk_pixdata_serialize(pixdata, &len);
 
-   g_object_unref(pixbuf);
+   gdk_pixbuf_unref(pixbuf);
    g_free(pixdata);
 
    return data;
@@ -1679,6 +1702,12 @@ const char *user_icon[] = {
    menu_hide_privates = GTK_CHECK_MENU_ITEM(gtk_item_factory_get_widget(
                                             item_factory,
                                             _("/View/Hide Private Records")));
+   menu_show_privates = GTK_CHECK_MENU_ITEM(gtk_item_factory_get_widget(
+                                            item_factory,
+                                            _("/View/Show Private Records")));
+   menu_mask_privates = GTK_CHECK_MENU_ITEM(gtk_item_factory_get_widget(
+                                            item_factory,
+                                            _("/View/Mask Private Records")));
 }
 
 static void cb_delete_event(GtkWidget *widget, GdkEvent *event, gpointer data)
@@ -2246,40 +2275,40 @@ char * xpm_backup[] = {
 
    /* parse command line options */
    for (i=1; i<argc; i++) {
-      if (!strncasecmp(argv[i], "-v", 2)) {
+      if (!strncasecmp(argv[i], "-v", 3)) {
 	 char options[1024];
 	 get_compile_options(options, sizeof(options));
 	 printf("\n%s\n", options);
 	 exit(0);
       }
-      if ( (!strncasecmp(argv[i], "-h", 2)) ||
-	  (!strncasecmp(argv[i], "-?", 2)) ) {
+      if ( (!strncasecmp(argv[i], "-h", 3)) ||
+	  (!strncasecmp(argv[i], "-?", 3)) ) {
 	 fprint_usage_string(stderr);
 	 exit(0);
       }
-      if (!strncasecmp(argv[i], "-d", 2)) {
+      if (!strncasecmp(argv[i], "-d", 3)) {
 	 glob_log_stdout_mask = 0xFFFF;
 	 glob_log_file_mask = 0xFFFF;
 	 jp_logf(JP_LOG_DEBUG, "Debug messages on.\n");
       }
-      if (!strncasecmp(argv[i], "-p", 2)) {
+      if (!strncasecmp(argv[i], "-p", 3)) {
 	 skip_plugins = TRUE;
 	 jp_logf(JP_LOG_INFO, _("Not loading plugins.\n"));
       }
-      if (!strncmp(argv[i], "-A", 2)) {
+      if (!strncmp(argv[i], "-A", 3)) {
 	 skip_all_alarms = TRUE;
 	 jp_logf(JP_LOG_INFO, _("Ignoring all alarms.\n"));
       }
-      if (!strncmp(argv[i], "-a", 2)) {
+      if (!strncmp(argv[i], "-a", 3)) {
 	 skip_past_alarms = TRUE;
 	 jp_logf(JP_LOG_INFO, _("Ignoring past alarms.\n"));
       }
-      if ( (!strncmp(argv[i], "-s", 2)) ||
-           (!strncmp(argv[i], "--remote-sync", 13))) {
+      if ( (!strncmp(argv[i], "-s", 3)) ||
+           (!strncmp(argv[i], "--remote-sync", 14))) {
 	 remote_sync = TRUE;
       }
-      if ( (!strncasecmp(argv[i], "-i", 2)) ||
-           (!strncasecmp(argv[i], "--iconic", 8))){
+      if ( (!strncasecmp(argv[i], "-i", 3)) ||
+           (!strncasecmp(argv[i], "--iconic", 9))){
 	 iconify = 1;
       }
       if (!strncasecmp(argv[i], "-geometry", 9)) {
