@@ -1,4 +1,4 @@
-/* $Id: memo_gui.c,v 1.100 2007-11-06 20:12:45 rikster5 Exp $ */
+/* $Id: memo_gui.c,v 1.115 2008/05/25 09:46:20 rousseau Exp $ */
 
 /*******************************************************************************
  * memo_gui.c
@@ -48,7 +48,13 @@
 #define CONNECT_SIGNALS 400
 #define DISCONNECT_SIGNALS 401
 
+/* Keeps track of whether code is using Memo, or Memos database
+ * 0 is Memo, 1 is Memos */
+static long memo_version=0;
+
 extern GtkTooltips *glob_tooltips;
+extern GtkWidget *glob_date_label;
+extern int glob_date_timer_tag;
 
 struct MemoAppInfo memo_app_info;
 static int memo_category = CATEGORY_ALL;
@@ -254,7 +260,7 @@ int memo_print()
 /*
  * Start Import Code
  */
-int memo_import_callback(GtkWidget *parent_window, const char *file_path, int type)
+int cb_memo_import(GtkWidget *parent_window, const char *file_path, int type)
 {
    FILE *in;
    char line[256];
@@ -273,11 +279,6 @@ int memo_import_callback(GtkWidget *parent_window, const char *file_path, int ty
    int new_cat_num;
    int priv;
 
-   memo_get_details(&new_memo, &attrib);
-   if (new_memo.text) {
-      free_Memo(&new_memo);
-   }
-
    in=fopen(file_path, "r");
    if (!in) {
       jp_logf(JP_LOG_WARN, _("Unable to open file: %s\n"), file_path);
@@ -287,6 +288,11 @@ int memo_import_callback(GtkWidget *parent_window, const char *file_path, int ty
    /* TEXT */
    if (type==IMPORT_TYPE_TEXT) {
       jp_logf(JP_LOG_DEBUG, "Memo import text [%s]\n", file_path);
+
+      /* Trick to get currently selected category into attrib */
+      memo_get_details(&new_memo, &attrib);
+      free_Memo(&new_memo);
+
       text_len=0;
       text[0]='\0';
       while (!feof(in)) {
@@ -310,7 +316,6 @@ int memo_import_callback(GtkWidget *parent_window, const char *file_path, int ty
       jp_charset_p2j(text, sizeof(text));
       text_len = strlen(text);
 #endif
-
 #ifdef JPILOT_DEBUG
       printf("text=[%s]\n", text);
       printf("text_len=%d\n", text_len);
@@ -318,6 +323,7 @@ int memo_import_callback(GtkWidget *parent_window, const char *file_path, int ty
 #endif
 
       new_memo.text=text;
+
       ret=import_record_ask(parent_window, pane,
 			    new_memo.text,
 			    &(memo_app_info.category),
@@ -334,37 +340,36 @@ int memo_import_callback(GtkWidget *parent_window, const char *file_path, int ty
    /* CSV */
    if (type==IMPORT_TYPE_CSV) {
       jp_logf(JP_LOG_DEBUG, "Memo import CSV [%s]\n", file_path);
-      /* The first line is format, so we don't need it */
-      fgets(text, 1000, in);
+      /* Skip the first line which contains the format */
+      fgets(text, sizeof(text), in);
+
       import_all=FALSE;
       while (1) {
 	 /* Read the category field */
-	 ret = read_csv_field(in, text, 65535);
+	 ret = read_csv_field(in, text, sizeof(text));
 	 if (feof(in)) break;
 #ifdef JPILOT_DEBUG
 	 printf("category is [%s]\n", text);
 #endif
 	 g_strlcpy(old_cat_name, text, 17);
-	 attrib=0;
 	 /* Figure out what the best category number is */
 	 suggested_cat_num=0;
 	 for (i=0; i<NUM_MEMO_CAT_ITEMS; i++) {
-	    if (memo_app_info.category.name[i][0]=='\0') continue;
+	    if (!memo_app_info.category.name[i][0]) continue;
 	    if (!strcmp(memo_app_info.category.name[i], old_cat_name)) {
 	       suggested_cat_num=i;
-	       i=1000;
 	       break;
 	    }
 	 }
 
 	 /* Read the private field */
-	 ret = read_csv_field(in, text, 65535);
+	 ret = read_csv_field(in, text, sizeof(text));
 #ifdef JPILOT_DEBUG
 	 printf("private is [%s]\n", text);
 #endif
 	 sscanf(text, "%d", &priv);
 
-	 ret = read_csv_field(in, text, 65535);
+	 ret = read_csv_field(in, text, sizeof(text));
 #ifdef JPILOT_DEBUG
 	 printf("memo text is [%s]\n", text);
 #endif
@@ -382,9 +387,8 @@ int memo_import_callback(GtkWidget *parent_window, const char *file_path, int ty
 	 }
 	 if (ret==DIALOG_SAID_IMPORT_QUIT) break;
 	 if (ret==DIALOG_SAID_IMPORT_SKIP) continue;
-	 if (ret==DIALOG_SAID_IMPORT_ALL) {
-	    import_all=TRUE;
-	 }
+	 if (ret==DIALOG_SAID_IMPORT_ALL)  import_all=TRUE;
+
 	 attrib = (new_cat_num & 0x0F) |
 	   (priv ? dlpRecAttrSecret : 0);
 	 if ((ret==DIALOG_SAID_IMPORT_YES) || (import_all)) {
@@ -428,7 +432,6 @@ int memo_import_callback(GtkWidget *parent_window, const char *file_path, int ty
 	       if (memo_app_info.category.name[i][0]=='\0') continue;
 	       if (!strcmp(memo_app_info.category.name[i], old_cat_name)) {
 		  suggested_cat_num=i;
-		  i=1000;
 		  break;
 	       }
 	    }
@@ -448,9 +451,8 @@ int memo_import_callback(GtkWidget *parent_window, const char *file_path, int ty
 	 }
 	 if (ret==DIALOG_SAID_IMPORT_QUIT) break;
 	 if (ret==DIALOG_SAID_IMPORT_SKIP) continue;
-	 if (ret==DIALOG_SAID_IMPORT_ALL) {
-	    import_all=TRUE;
-	 }
+	 if (ret==DIALOG_SAID_IMPORT_ALL)  import_all=TRUE;
+
 	 attrib = (new_cat_num & 0x0F) |
 	   ((temp_memolist->mmemo.attrib & 0x10) ? dlpRecAttrSecret : 0);
 	 if ((ret==DIALOG_SAID_IMPORT_YES) || (import_all)) {
@@ -480,7 +482,14 @@ int memo_import(GtkWidget *window)
       0
    };
 
-   import_gui(window, pane, type_desc, type_int, memo_import_callback);
+   /* Hide ABA import of Memos until file format has been decoded */
+   if (memo_version==1) {
+      type_desc[2] = NULL;
+      type_int[2] = 0;
+
+   }
+
+   import_gui(window, pane, type_desc, type_int, cb_memo_import);
    return EXIT_SUCCESS;
 }
 /*
@@ -498,7 +507,7 @@ void cb_memo_export_ok(GtkWidget *export_window, GtkWidget *clist,
    GList *list, *temp_list;
    FILE *out;
    struct stat statb;
-   int i, r, num, len;
+   int i, r, len;
    const char *short_date;
    time_t ltime;
    struct tm *now;
@@ -506,11 +515,14 @@ void cb_memo_export_ok(GtkWidget *export_window, GtkWidget *clist,
    char *button_overwrite_text[]={N_("No"), N_("Yes")};
    char text[1024];
    char str1[256], str2[256];
+   char date_string[1024];
    char pref_time[40];
    char *csv_text;
+   long char_set;
+   char *utf;
 
-   list=GTK_CLIST(clist)->selection;
-
+   /* Open file for export, including corner cases where file exists or 
+    * can't be opened */
    if (!stat(filename, &statb)) {
       if (S_ISDIR(statb.st_mode)) {
 	 g_snprintf(text, sizeof(text), _("%s is a directory"), filename);
@@ -537,8 +549,35 @@ void cb_memo_export_ok(GtkWidget *export_window, GtkWidget *clist,
       return;
    }
 
-   /* Count how many are to be exported */
-   for (num=0, temp_list=list; temp_list; temp_list = temp_list->next, num++);
+   /* Write a header for TEXT file */
+   if (type == EXPORT_TYPE_TEXT) {
+      get_pref(PREF_SHORTDATE, NULL, &short_date);
+      get_pref_time_no_secs(pref_time);
+      time(&ltime);
+      now = localtime(&ltime);
+      strftime(str1, sizeof(str1), short_date, now);
+      strftime(str2, sizeof(str2), pref_time, now);
+      g_snprintf(date_string, sizeof(date_string), "%s %s", str1, str2);
+      if (memo_version==0) {
+         fprintf(out, _("Memo exported from %s %s on %s\n\n"), 
+                                            PN,VERSION,date_string);
+      } else {
+         fprintf(out, _("Memos exported from %s %s on %s\n\n"), 
+                                             PN,VERSION,date_string);
+      }
+   }
+
+   /* Write a header to the CSV file */
+   if (type == EXPORT_TYPE_CSV) {
+      if (memo_version==0) {
+         fprintf(out, "CSV memo version "VERSION": Category, Private, Memo Text\n");
+      } else {
+         fprintf(out, "CSV memos version "VERSION": Category, Private, Memo Text\n");
+      }
+   }
+
+   get_pref(PREF_CHAR_SET, &char_set, NULL);
+   list=GTK_CLIST(clist)->selection;
 
    for (i=0, temp_list=list; temp_list; temp_list = temp_list->next, i++) {
       mmemo = gtk_clist_get_row_data(GTK_CLIST(clist), GPOINTER_TO_INT(temp_list->data));
@@ -548,9 +587,6 @@ void cb_memo_export_ok(GtkWidget *export_window, GtkWidget *clist,
       }
       switch (type) {
        case EXPORT_TYPE_CSV:
-	 if (i==0) {
-	    fprintf(out, "CSV memo: Category, Private, Memo Text\n");
-	 }
 	 len=0;
 	 if (mmemo->memo.text) {
 	    len=strlen(mmemo->memo.text) * 2 + 4;
@@ -561,13 +597,15 @@ void cb_memo_export_ok(GtkWidget *export_window, GtkWidget *clist,
 	    continue;
 	    jp_logf(JP_LOG_WARN, _("Can't export memo %d\n"), (long) temp_list->data + 1);
 	 }
-	 str_to_csv_str(csv_text, memo_app_info.category.name[mmemo->attrib & 0x0F]);
-	 fprintf(out, "\"%s\",", csv_text);
+	 utf = charset_p2newj(memo_app_info.category.name[mmemo->attrib & 0x0F], 16, char_set);
+	 fprintf(out, "\"%s\",", utf);
+	 g_free(utf);
 	 fprintf(out, "\"%s\",", (mmemo->attrib & dlpRecAttrSecret) ? "1":"0");
 	 str_to_csv_str(csv_text, mmemo->memo.text);
 	 fprintf(out, "\"%s\"\n", csv_text);
 	 free(csv_text);
 	 break;
+
        case EXPORT_TYPE_TEXT:
 	 get_pref(PREF_SHORTDATE, NULL, &short_date);
 	 get_pref_time_no_secs(pref_time);
@@ -577,16 +615,17 @@ void cb_memo_export_ok(GtkWidget *export_window, GtkWidget *clist,
 	 strftime(str2, sizeof(str2), pref_time, now);
 	 g_snprintf(text, sizeof(text), "%s %s", str1, str2);
 
-	 /* Todo Should I translate these? */
-	 fprintf(out, "Memo: %ld, exported from %s on %s\n",
-		 (long) temp_list->data + 1, PN, text);
-	 fprintf(out, "Category: %s\n", memo_app_info.category.name[mmemo->attrib & 0x0F]);
-	 fprintf(out, "This memo was marked as: %s\n",
-		 (mmemo->attrib & dlpRecAttrSecret) ? "Private":"Not Private");
-	 fprintf(out, "----- Start of Memo -----\n");
+	 fprintf(out, _("Memo: %ld\n"), (long) temp_list->data + 1);
+	 utf = charset_p2newj(memo_app_info.category.name[mmemo->attrib & 0x0F], 16, char_set);
+	 fprintf(out, _("Category: %s\n"), utf);
+	 g_free(utf);
+	 fprintf(out, _("Private: %s\n"),
+		 (mmemo->attrib & dlpRecAttrSecret) ? _("Yes"):_("No"));
+	 fprintf(out, _("----- Start of Memo -----\n"));
 	 fprintf(out, "%s", mmemo->memo.text);
-	 fprintf(out, "\n----- End of Memo -----\n\n");
+	 fprintf(out, _("\n----- End of Memo -----\n\n"));
 	 break;
+
        default:
 	 jp_logf(JP_LOG_WARN, _("Unknown export type\n"));
       }
@@ -937,6 +976,7 @@ static void clear_mymemo(MyMemo *mmemo)
 /* End Masking */
 
 
+#if 0
 static void cb_edit_cats(GtkWidget *widget, gpointer data)
 {
    struct MemoAppInfo ai;
@@ -993,14 +1033,12 @@ static void cb_edit_cats(GtkWidget *widget, gpointer data)
 
    size = pack_MemoAppInfo(&ai, buffer, sizeof(buffer));
 
-   if (memo_version==2) {
-      pdb_file_write_app_block("MemosDB-PMem", buffer, size);
-   } else {
-      pdb_file_write_app_block("MemoDB", buffer, size);
-   }
+   pdb_file_write_app_block(db_name, buffer, size);
+   
 
    cb_app_button(NULL, GINT_TO_POINTER(REDRAW));
 }
+#endif
 
 
 static void cb_clist_selection(GtkWidget      *clist,
@@ -1173,6 +1211,12 @@ static void memo_update_clist(GtkWidget *clist, GtkWidget *tooltip_widget,
 	   gtk_signal_disconnect_by_func(GTK_OBJECT(clist),
 				 GTK_SIGNAL_FUNC(cb_clist_selection), NULL);
    gtk_clist_clear(GTK_CLIST(clist));
+#ifdef __APPLE__
+   gtk_clist_thaw(GTK_CLIST(clist));
+   gtk_widget_hide(clist);
+   gtk_widget_show_all(clist);
+   gtk_clist_freeze(GTK_CLIST(clist));
+#endif
 
    show_priv = show_privates(GET_PRIVATES);
 
@@ -1252,8 +1296,10 @@ static void memo_update_clist(GtkWidget *clist, GtkWidget *tooltip_widget,
 
    jp_logf(JP_LOG_DEBUG, "entries_shown=%d\n", entries_shown);
 
-   gtk_signal_connect(GTK_OBJECT(clist), "select_row",
-		      GTK_SIGNAL_FUNC(cb_clist_selection), NULL);
+   if (main) {
+      gtk_signal_connect(GTK_OBJECT(clist), "select_row",
+               GTK_SIGNAL_FUNC(cb_clist_selection), NULL);
+   }
 
    /* If there are items in the list, highlight the selected row */
    if ((main) && (entries_shown>0)) {
@@ -1400,13 +1446,11 @@ int memo_gui_cleanup()
  */
 int memo_gui(GtkWidget *vbox, GtkWidget *hbox)
 {
-   extern GtkWidget *glob_date_label;
-   extern int glob_date_timer_tag;
    int i;
    GtkWidget *scrolled_window;
    GtkWidget *vbox1, *vbox2, *hbox_temp;
    GtkWidget *separator;
-   GtkWidget *button;
+   /*GtkWidget *button;*/
 #ifndef ENABLE_GTK2
    GtkWidget *vscrollbar;
 #endif
@@ -1415,6 +1459,8 @@ int memo_gui(GtkWidget *vbox, GtkWidget *hbox)
    long char_set;
    char *cat_name;
 
+   get_pref(PREF_MEMO_VERSION, &memo_version, NULL);
+
    clist_row_selected=0;
    record_changed=CLEAR_FLAG;
 
@@ -1493,11 +1539,14 @@ int memo_gui(GtkWidget *vbox, GtkWidget *hbox)
 
 
    /* Edit category button */
+	/* RW:5/8/2008: Temporarily removed ability to edit categories with Jpilot
+	 * because the back-end code WILL often lose user data */
+	/*
    button = gtk_button_new_with_label(_("Edit Categories"));
    gtk_signal_connect(GTK_OBJECT(button), "clicked",
 		      GTK_SIGNAL_FUNC(cb_edit_cats), NULL);
    gtk_box_pack_start(GTK_BOX(hbox_temp), button, FALSE, FALSE, 0);
-
+   */
    /* Put the memo list window up */
    scrolled_window = gtk_scrolled_window_new(NULL, NULL);
    /*gtk_widget_set_usize(GTK_WIDGET(scrolled_window), 330, 100); */
