@@ -1,4 +1,4 @@
-/* $Id: prefs.c,v 1.70 2007-10-25 18:53:32 rousseau Exp $ */
+/* $Id: prefs.c,v 1.75 2008/05/14 18:05:38 rikster5 Exp $ */
 
 /*******************************************************************************
  * prefs.c
@@ -99,7 +99,7 @@ static prefType glob_prefs[NUM_PREFS] = {
      {"memo_import_path", CHARTYPE, CHARTYPE, 0, NULL, 0},
      {"manana_mode", INTTYPE, INTTYPE, 0, NULL, 0},
      {"sync_manana", INTTYPE, INTTYPE, 0, NULL, 0},
-     {"use_jos", INTTYPE, INTTYPE, 0, ""},
+     {"use_jos", INTTYPE, INTTYPE, 0, NULL, 0},
      {"phone_prefix1", CHARTYPE, CHARTYPE, 0, NULL, 0},
      {"phone_prefix1_on", INTTYPE, INTTYPE, 0, NULL, 0},
      {"phone_prefix2", CHARTYPE, CHARTYPE, 0, NULL, 0},
@@ -139,6 +139,8 @@ static prefType glob_prefs[NUM_PREFS] = {
      {"contacts_photo_filename", CHARTYPE, CHARTYPE, 0, NULL, 0},
      {"todo_sort_column", INTTYPE, INTTYPE, 1, NULL, 0},
      {"todo_sort_order", INTTYPE, INTTYPE, 0, NULL, 0},
+     {"addr_sort_order", INTTYPE, INTTYPE, 1, NULL, 0},
+     {"addr_name_col_sz", INTTYPE, INTTYPE, 140, NULL, 0},
 };
 
 struct name_list {
@@ -180,7 +182,7 @@ void pref_init()
 	 glob_prefs[i].svalue_size=strlen(glob_prefs[i].svalue)+1;
 	 break;
        case PREF_MAIL_COMMAND:
-	 glob_prefs[i].svalue=strdup("mozilla-thunderbird -remote \"mailto(\%s)\"");
+	 glob_prefs[i].svalue=strdup("mozilla-thunderbird -remote \"mailto(%s)\"");
 	 glob_prefs[i].svalue_size=strlen(glob_prefs[i].svalue)+1;
 	 break;
        default:
