@@ -1,4 +1,4 @@
-/* $Id: todo_gui.c,v 1.114 2007-11-25 12:12:33 rousseau Exp $ */
+/* $Id: todo_gui.c,v 1.129 2008/05/25 09:46:20 rousseau Exp $ */
 
 /*******************************************************************************
  * todo_gui.c
@@ -49,7 +49,18 @@
 #define CONNECT_SIGNALS 400
 #define DISCONNECT_SIGNALS 401
 
+#ifndef max
+#  define max(a,b) (((a) > (b)) ? (a) : (b))
+#endif
+
+
+/* Keeps track of whether code is using ToDo, or Tasks database
+ * 0 is ToDo, 1 is Tasks */
+static long todo_version=0;
+
 extern GtkTooltips *glob_tooltips;
+extern GtkWidget *glob_date_label;
+extern int glob_date_timer_tag;
 
 static GtkWidget *clist;
 static GtkWidget *todo_text, *todo_text_note;
@@ -394,7 +405,7 @@ Description: %s\nNote: %s\n", due, todo->priority, complete,
 /*
  * Start Import Code
  */
-int todo_import_callback(GtkWidget *parent_window, const char *file_path, int type)
+int cb_todo_import(GtkWidget *parent_window, const char *file_path, int type)
 {
    FILE *in;
    char text[65536];
@@ -413,9 +424,6 @@ int todo_import_callback(GtkWidget *parent_window, const char *file_path, int ty
    int priv, indefinite, priority, completed;
    int year, month, day;
 
-   todo_get_details(&new_todo, &attrib);
-   free_ToDo(&new_todo);
-
    in=fopen(file_path, "r");
    if (!in) {
       jp_logf(JP_LOG_WARN, _("Unable to open file: %s\n"), file_path);
@@ -425,8 +433,9 @@ int todo_import_callback(GtkWidget *parent_window, const char *file_path, int ty
    /* CSV */
    if (type==IMPORT_TYPE_CSV) {
       jp_logf(JP_LOG_DEBUG, "Todo import CSV [%s]\n", file_path);
-      /* The first line is format, so we don't need it */
+      /* Skip the first line which contains the format */
       fgets(text, sizeof(text), in);
+
       import_all=FALSE;
       while (1) {
 	 /* Read the category field */
@@ -443,7 +452,6 @@ int todo_import_callback(GtkWidget *parent_window, const char *file_path, int ty
 	    if (todo_app_info.category.name[i][0]=='\0') continue;
 	    if (!strcmp(todo_app_info.category.name[i], old_cat_name)) {
 	       suggested_cat_num=i;
-	       i=1000;
 	       break;
 	    }
 	 }
@@ -467,7 +475,7 @@ int todo_import_callback(GtkWidget *parent_window, const char *file_path, int ty
 #ifdef JPILOT_DEBUG
 	 printf("due date is [%s]\n", text);
 #endif
-	 sscanf(text, "%d %d %d", &year, &month, &day);
+	 sscanf(text, "%d/%d/%d", &year, &month, &day);
 
 	 /* Read the Priority field */
 	 ret = read_csv_field(in, text, sizeof(text));
@@ -501,6 +509,7 @@ int todo_import_callback(GtkWidget *parent_window, const char *file_path, int ty
 	 new_todo.due.tm_mon=month-1;
 	 new_todo.due.tm_mday=day;
 	 new_todo.priority=priority;
+	 new_todo.complete=completed;
 	 new_todo.description=description;
 	 new_todo.note=note;
 
@@ -518,9 +527,8 @@ int todo_import_callback(GtkWidget *parent_window, const char *file_path, int ty
 	 }
 	 if (ret==DIALOG_SAID_IMPORT_QUIT) break;
 	 if (ret==DIALOG_SAID_IMPORT_SKIP) continue;
-	 if (ret==DIALOG_SAID_IMPORT_ALL) {
-	    import_all=TRUE;
-	 }
+	 if (ret==DIALOG_SAID_IMPORT_ALL)  import_all=TRUE;
+
 	 attrib = (new_cat_num & 0x0F) |
 	   (priv ? dlpRecAttrSecret : 0);
 	 if ((ret==DIALOG_SAID_IMPORT_YES) || (import_all)) {
@@ -548,7 +556,6 @@ int todo_import_callback(GtkWidget *parent_window, const char *file_path, int ty
 	 } else {
 	    g_strlcpy(old_cat_name, cai.name[index], 17);
 	 }
-	 attrib=0;
 	 /* Figure out what category it was in the dat file */
 	 index=temp_todolist->mtodo.unique_id-1;
 	 suggested_cat_num=0;
@@ -557,7 +564,6 @@ int todo_import_callback(GtkWidget *parent_window, const char *file_path, int ty
 	       if (todo_app_info.category.name[i][0]=='\0') continue;
 	       if (!strcmp(todo_app_info.category.name[i], old_cat_name)) {
 		  suggested_cat_num=i;
-		  i=1000;
 		  break;
 	       }
 	    }
@@ -578,9 +584,8 @@ int todo_import_callback(GtkWidget *parent_window, const char *file_path, int ty
 	 }
 	 if (ret==DIALOG_SAID_IMPORT_QUIT) break;
 	 if (ret==DIALOG_SAID_IMPORT_SKIP) continue;
-	 if (ret==DIALOG_SAID_IMPORT_ALL) {
-	    import_all=TRUE;
-	 }
+	 if (ret==DIALOG_SAID_IMPORT_ALL)  import_all=TRUE;
+
 	 attrib = (new_cat_num & 0x0F) |
 	   ((temp_todolist->mtodo.attrib & 0x10) ? dlpRecAttrSecret : 0);
 	 if ((ret==DIALOG_SAID_IMPORT_YES) || (import_all)) {
@@ -609,7 +614,7 @@ int todo_import(GtkWidget *window)
       0
    };
 
-   import_gui(window, pane, type_desc, type_int, todo_import_callback);
+   import_gui(window, pane, type_desc, type_int, cb_todo_import);
    return EXIT_SUCCESS;
 }
 /*
@@ -627,13 +632,14 @@ void cb_todo_export_ok(GtkWidget *export_window, GtkWidget *clist,
    GList *list, *temp_list;
    FILE *out;
    struct stat statb;
-   int i, r, len;
+   int i, r, len1, len2;
    const char *short_date;
    time_t ltime;
-   struct tm *now;
+   struct tm *now = NULL;
    char *button_text[]={N_("OK")};
    char *button_overwrite_text[]={N_("No"), N_("Yes")};
    char text[1024];
+   char date_string[1024];
    char str1[256], str2[256];
    char pref_time[40];
    char *csv_text;
@@ -642,19 +648,11 @@ void cb_todo_export_ok(GtkWidget *export_window, GtkWidget *clist,
    char hostname[256];
    const char *svalue;
    long userid;
+   long char_set;
+   char *utf;
 
-   /* this stuff is for ical only. */
-   /* todo: create a pre-export switch */
-   get_pref(PREF_USER, NULL, &svalue);
-   g_strlcpy(text, svalue, sizeof(text));
-   str_to_ical_str(username, sizeof(username), text);
-   get_pref(PREF_USER_ID, &userid, NULL);
-   gethostname(text, sizeof(text));
-   text[sizeof(text)-1]='\0';
-   str_to_ical_str(hostname, sizeof(hostname), text);
-
-   list=GTK_CLIST(clist)->selection;
-
+   /* Open file for export, including corner cases where file exists or 
+    * can't be opened */
    if (!stat(filename, &statb)) {
       if (S_ISDIR(statb.st_mode)) {
 	 g_snprintf(text, sizeof(text), _("%s is a directory"), filename);
@@ -681,9 +679,40 @@ void cb_todo_export_ok(GtkWidget *export_window, GtkWidget *clist,
       return;
    }
 
-   time(&ltime);
-   now = gmtime(&ltime);
-   /* XXX ical wants gmtime, text wants localtime */
+   /* Special setup for ICAL export */
+   if (type == EXPORT_TYPE_ICALENDAR) {
+      get_pref(PREF_USER, NULL, &svalue);
+      g_strlcpy(text, svalue, 128);
+      str_to_ical_str(username, sizeof(username), text);
+      get_pref(PREF_USER_ID, &userid, NULL);
+      gethostname(text, sizeof(text));
+      text[sizeof(text)-1]='\0';
+      str_to_ical_str(hostname, sizeof(hostname), text);
+
+      time(&ltime);
+      now = gmtime(&ltime);
+   }
+
+   /* Write a header for TEXT file */
+   if (type == EXPORT_TYPE_TEXT) {
+      get_pref(PREF_SHORTDATE, NULL, &short_date);
+      get_pref_time_no_secs(pref_time);
+      time(&ltime);
+      now = localtime(&ltime);
+      strftime(str1, sizeof(str1), short_date, now);
+      strftime(str2, sizeof(str2), pref_time, now);
+      g_snprintf(date_string, sizeof(date_string), "%s %s", str1, str2);
+      fprintf(out, _("ToDo exported from %s %s on %s\n\n"), 
+                                         PN,VERSION,date_string);
+   }
+
+   /* Write a header to the CSV file */
+   if (type == EXPORT_TYPE_CSV) {
+      fprintf(out, "CSV todo version "VERSION": Category, Private, Indefinite, Due Date, Priority, Completed, ToDo Text, Note\n");
+   }
+
+   get_pref(PREF_CHAR_SET, &char_set, NULL);
+   list=GTK_CLIST(clist)->selection;
 
    for (i=0, temp_list=list; temp_list; temp_list = temp_list->next, i++) {
       mtodo = gtk_clist_get_row_data(GTK_CLIST(clist), GPOINTER_TO_INT(temp_list->data));
@@ -693,29 +722,31 @@ void cb_todo_export_ok(GtkWidget *export_window, GtkWidget *clist,
       }
       switch (type) {
        case EXPORT_TYPE_CSV:
-	 if (i==0) {
-	    fprintf(out, "CSV todo: Category, Private, Indefinite, Due Date, Priority, Completed, ToDo Text, Note\n");
-	 }
-	 len=0;
+	 len1=len2=0;
 	 if (mtodo->todo.description) {
-	    len=strlen(mtodo->todo.description) * 2 + 4;
+	    len1=strlen(mtodo->todo.description) * 2 + 4;
 	 }
-	 if (len<256) len=256;
-	 csv_text=malloc(len);
+	 if (mtodo->todo.note) {
+	    len2=strlen(mtodo->todo.note) * 2 + 4;
+	 }
+         len1 = max(len1, len2);
+	 if (len1<256) len1=256;
+	 csv_text=malloc(len1);
 	 if (!csv_text) {
 	    continue;
 	    jp_logf(JP_LOG_WARN, _("Can't export todo %d\n"), (long) temp_list->data + 1);
 	 }
-	 str_to_csv_str(csv_text, todo_app_info.category.name[mtodo->attrib & 0x0F]);
-	 fprintf(out, "\"%s\",", csv_text);
+	 utf = charset_p2newj(todo_app_info.category.name[mtodo->attrib & 0x0F], 16, char_set);
+	 fprintf(out, "\"%s\",", utf);
+	 g_free(utf);
 	 fprintf(out, "\"%s\",", (mtodo->attrib & dlpRecAttrSecret) ? "1":"0");
 	 fprintf(out, "\"%s\",", mtodo->todo.indefinite ? "1":"0");
 	 if (mtodo->todo.indefinite) {
-	    csv_text[0]='\0';
+	    fprintf(out, "\"\",");
 	 } else {
-	    strftime(csv_text, len, "%Y %02m %02d", &(mtodo->todo.due));
+	    strftime(text, sizeof(text), "%Y/%02m/%02d", &(mtodo->todo.due));
+	    fprintf(out, "\"%s\",", text);
 	 }
-	 fprintf(out, "\"%s\",", csv_text);
 	 fprintf(out, "\"%d\",", mtodo->todo.priority);
 	 fprintf(out, "\"%s\",", mtodo->todo.complete ? "1":"0");
 	 if (mtodo->todo.description) {
@@ -732,35 +763,30 @@ void cb_todo_export_ok(GtkWidget *export_window, GtkWidget *clist,
 	 }
 	 free(csv_text);
 	 break;
-       case EXPORT_TYPE_TEXT:
-	 get_pref(PREF_SHORTDATE, NULL, &short_date);
-	 get_pref_time_no_secs(pref_time);
-	 time(&ltime);
-	 now = localtime(&ltime);
-	 strftime(str1, sizeof(str1), short_date, now);
-	 strftime(str2, sizeof(str2), pref_time, now);
-	 g_snprintf(text, sizeof(text), "%s %s", str1, str2);
 
-	 /* Todo Should I translate these? */
-	 fprintf(out, "ToDo: exported from %s on %s\n", PN, text);
-	 fprintf(out, "Category: %s\n", todo_app_info.category.name[mtodo->attrib & 0x0F]);
-	 fprintf(out, "Private: %s\n",
-		 (mtodo->attrib & dlpRecAttrSecret) ? "Yes":"No");
+       case EXPORT_TYPE_TEXT:
+	 utf = charset_p2newj(todo_app_info.category.name[mtodo->attrib & 0x0F], 16, char_set);
+	 fprintf(out, _("Category: %s\n"), utf);
+	 g_free(utf);
+
+	 fprintf(out, _("Private: %s\n"),
+		 (mtodo->attrib & dlpRecAttrSecret) ? _("Yes"):_("No"));
 	 if (mtodo->todo.indefinite) {
-	    fprintf(out, "Due Date: Indefinite\n");
+	    fprintf(out, _("Due Date: None\n"));
 	 } else {
-	    strftime(text, sizeof(text), "%Y %02m %02d", &(mtodo->todo.due));
-	    fprintf(out, "Due Date: %s\n", text);
+            strftime(text, sizeof(text), short_date, &(mtodo->todo.due));
+	    fprintf(out, _("Due Date: %s\n"), text);
 	 }
-	 fprintf(out, "Priority: %d\n", mtodo->todo.priority);
-	 fprintf(out, "Completed: %s\n", mtodo->todo.complete ? "Yes":"No");
+	 fprintf(out, _("Priority: %d\n"), mtodo->todo.priority);
+	 fprintf(out, _("Completed: %s\n"), mtodo->todo.complete ? _("Yes"):_("No"));
 	 if (mtodo->todo.description) {
-	    fprintf(out, "Description: %s\n", mtodo->todo.description);
+	    fprintf(out, _("Description: %s\n"), mtodo->todo.description);
 	 }
 	 if (mtodo->todo.note) {
-	    fprintf(out, "Note: %s\n", mtodo->todo.note);
+	    fprintf(out, _("Note: %s\n\n"), mtodo->todo.note);
 	 }
 	 break;
+
        case EXPORT_TYPE_ICALENDAR:
 	 /* RFC 2445: Internet Calendaring and Scheduling Core
 	  *           Object Specification */
@@ -1261,6 +1287,7 @@ static void clear_mytodos(MyToDo *mtodo)
 }
 /* End Masking */
 
+#if 0
 static void cb_edit_cats(GtkWidget *widget, gpointer data)
 {
    struct ToDoAppInfo ai;
@@ -1301,6 +1328,7 @@ static void cb_edit_cats(GtkWidget *widget, gpointer data)
 
    cb_app_button(NULL, GINT_TO_POINTER(REDRAW));
 }
+#endif
 
 /* Function is used to sort clist based on the completed checkbox */
 gint GtkClistCompareCheckbox(GtkCList *clist,
@@ -1683,6 +1711,12 @@ void todo_update_clist(GtkWidget *clist, GtkWidget *tooltip_widget,
 				    GTK_SIGNAL_FUNC(cb_clist_selection), NULL);
    }
    gtk_clist_clear(GTK_CLIST(clist));
+#ifdef __APPLE__
+   gtk_clist_thaw(GTK_CLIST(clist));
+   gtk_widget_hide(clist);
+   gtk_widget_show_all(clist);
+   gtk_clist_freeze(GTK_CLIST(clist));
+#endif
 
    /* Collect preferences and constant pixmaps for loop */
    get_pref(PREF_TODO_HIDE_COMPLETED, &hide_completed, NULL);
@@ -1698,7 +1732,6 @@ void todo_update_clist(GtkWidget *clist, GtkWidget *tooltip_widget,
 #endif
 
    entries_shown=0;
-   show_priv = show_privates(GET_PRIVATES);
    for (temp_todo = *todo_list, i=0; temp_todo; temp_todo=temp_todo->next) {
       if ( ((temp_todo->mtodo.attrib & 0x0F) != category) &&
 	  category != CATEGORY_ALL) {
@@ -2005,8 +2038,6 @@ int todo_gui_cleanup()
 
 int todo_gui(GtkWidget *vbox, GtkWidget *hbox)
 {
-   extern GtkWidget *glob_date_label;
-   extern int glob_date_timer_tag;
    GtkWidget *scrolled_window;
    GtkWidget *pixmapwid;
    GdkPixmap *pixmap;
@@ -2018,7 +2049,7 @@ int todo_gui(GtkWidget *vbox, GtkWidget *hbox)
 #ifndef ENABLE_GTK2
    GtkWidget *vscrollbar;
 #endif
-   GtkWidget *button;
+   /*GtkWidget *button;*/
    time_t ltime;
    struct tm *now;
    char str[MAX_RADIO_BUTTON_LEN];
@@ -2031,6 +2062,8 @@ int todo_gui(GtkWidget *vbox, GtkWidget *hbox)
    long char_set;
    char *cat_name;
 
+   get_pref(PREF_TODO_VERSION, &todo_version, NULL);
+
    init();
 
    /* Do some initialization */
@@ -2106,10 +2139,14 @@ int todo_gui(GtkWidget *vbox, GtkWidget *hbox)
    gtk_box_pack_start(GTK_BOX(hbox_temp), category_menu1, TRUE, TRUE, 0);
 
    /* Edit category button */
+	/* RW:5/8/2008: Temporarily removed ability to edit categories with Jpilot
+	 * because the back-end code WILL often lose user data */
+	/*
    button = gtk_button_new_with_label(_("Edit Categories"));
    gtk_signal_connect(GTK_OBJECT(button), "clicked",
 		      GTK_SIGNAL_FUNC(cb_edit_cats), NULL);
    gtk_box_pack_start(GTK_BOX(hbox_temp), button, FALSE, FALSE, 0);
+   */
 
    /*Put the todo list window up */
    scrolled_window = gtk_scrolled_window_new(NULL, NULL);
@@ -2129,14 +2166,14 @@ int todo_gui(GtkWidget *vbox, GtkWidget *hbox)
    mask = NULL;
 #endif
    pixmapwid = gtk_pixmap_new(pixmap, mask);
-   hack_clist_set_column_title_pixmap(clist, TODO_NOTE_COLUMN, pixmapwid);
+   gtk_clist_set_column_widget(GTK_CLIST(clist), TODO_NOTE_COLUMN, pixmapwid);
 
    get_pixmaps(vbox, PIXMAP_BOX_CHECKED, &pixmap, &mask);
 #ifdef __APPLE__
    mask = NULL;
 #endif
    pixmapwid = gtk_pixmap_new(pixmap, mask);
-   hack_clist_set_column_title_pixmap(clist, TODO_CHECK_COLUMN, pixmapwid);
+   gtk_clist_set_column_widget(GTK_CLIST(clist), TODO_CHECK_COLUMN, pixmapwid);
 
    gtk_clist_column_titles_active(GTK_CLIST(clist));
    gtk_signal_connect(GTK_OBJECT(clist), "click_column",
