@@ -1,4 +1,4 @@
-/* $Id: utils.h,v 1.58 2007-10-25 18:53:33 rousseau Exp $ */
+/* $Id: utils.h,v 1.61 2008/04/29 14:21:24 rikster5 Exp $ */
 
 /*******************************************************************************
  * utils.h
@@ -272,14 +272,6 @@ int get_pixmaps(GtkWidget *widget,
 		GdkPixmap **out_pixmap,
 		GdkBitmap **out_mask);
 
-/*
- * This is a hack to add pixmaps in column titles.
- * Its a hack because it assumes things about GTK that are not exposed.
- */
-int hack_clist_set_column_title_pixmap(GtkWidget *clist,
-				       int column,
-				       GtkWidget *pixmapwid);
-
 int check_hidden_dir();
 
 int read_gtkrc_file();
@@ -355,6 +347,8 @@ void set_bg_rgb_clist_row(GtkWidget *clist, int row, int r, int g, int b);
 
 void set_fg_rgb_clist_cell(GtkWidget *clist, int row, int col, int r, int g, int b);
 
+void entry_set_multiline_truncate(GtkEntry *entry, gboolean value);
+
 void clist_select_row(GtkCList *clist, 
                       int       row,
 		      int       column);
@@ -472,6 +466,23 @@ int add_years_to_date(struct tm *date, int n);
 
 int sub_years_from_date(struct tm *date, int n);
 
+time_t mktime_dst_adj(struct tm *tm);
+
+int dateToDays(struct tm *tm1);
+
+int find_prev_next(struct Appointment *appt,
+                   time_t adv,
+                   struct tm *date1,
+                   struct tm *date2,
+                   struct tm *tm_prev,
+                   struct tm *tm_next,
+                   int *prev_found,
+		   int *next_found);
+
+int find_next_rpt_event(struct Appointment *appt,
+                        struct tm *srch_start_tm,
+                        struct tm *next_tm);
+
 /*from jpilot.c */
 void cb_app_button(GtkWidget *widget, gpointer data);
 
